@@ -1,20 +1,21 @@
 import logging
 
-from typing import Optional, Union, Dict, Any, Tuple, Optional, Generator
+from typing import TYPE_CHECKING, Dict, Any, Tuple, Optional, Generator, cast
 from contextlib import contextmanager
 
-from requests.models import Response
 from locust.user.users import User
 from locust.clients import ResponseContextManager, HttpSession
 from locust.event import EventHook
 from paramiko import SFTPClient, Transport
 from paramiko.pkey import PKey
 
-from .task import RequestTask
+if TYPE_CHECKING:  # pragma: no cover
+    from .tasks import RequestTask
 
 
 logger = logging.getLogger(__name__)
 
+
 class ResponseEventSession(HttpSession):
     event_hook: EventHook
 
@@ -23,25 +24,35 @@ class ResponseEventSession(HttpSession):
 
         self.event_hook = EventHook()
 
-    def request(
+    def request(  # type: ignore
         self,
         method: str,
         url: str,
-        name: str,
-        request: Optional[RequestTask] = None,
+        name: Optional[str] = None,
         catch_response: bool = False,
+        context: Optional[Dict[str, Any]] = None,
+        request: Optional['RequestTask'] = None,
         **kwargs: Dict[str, Any],
-    ) -> Union[ResponseContextManager, Response]:
-        response = super().request(method, url, name, catch_response, **kwargs)
+    ) -> ResponseContextManager:
+
+        if context is None:
+            context = {}
+
+        response_context_manager = cast(
+            ResponseContextManager,
+            super().request(method, url, name, catch_response, context, **kwargs),
+        )
+
+        response_context_manager._entered = True
 
         self.event_hook.fire(
             name=name,
             request=request,
-            context=response,
+            context=response_context_manager,
             user=self.user,
         )
 
-        return response
+        return response_context_manager
 
 
 class SftpClientSession:
