@@ -14,11 +14,11 @@ from locust.clients import ResponseContextManager
 
 from grizzly_extras.transformer import PlainTransformer, transformer, TransformerError, TransformerContentType
 
-from ..users.meta import ContextVariables
+from ..users.base import GrizzlyUser
 from ..context import GrizzlyContext
 from ..exceptions import ResponseHandlerError, TransformerLocustError
 from ..types import HandlerType, RequestMethod, ResponseTarget, ResponseAction
-from ..task import RequestTask
+from ..tasks import RequestTask
 
 logger = logging.getLogger(__name__)
 
@@ -34,7 +34,7 @@ def create_request_task(
 
 
 def _create_request_task(
-    base_dir: str,method: RequestMethod, source: Optional[str], endpoint: str, name: Optional[str] = None, substitutes: Optional[Dict[str, str]] = None,
+    base_dir: str, method: RequestMethod, source: Optional[str], endpoint: str, name: Optional[str] = None, substitutes: Optional[Dict[str, str]] = None,
 ) -> RequestTask:
     if substitutes is None:
         substitutes = {}
@@ -112,7 +112,7 @@ def add_request_task(
     for row in table:
         if endpoint is None:
             if scenario_tasks_count == 0:
-                raise ValueError(f'no endpoint specified')
+                raise ValueError('no endpoint specified')
 
             last_request = grizzly.scenario.tasks[-1]
 
@@ -120,7 +120,7 @@ def add_request_task(
                 raise ValueError('previous task was not a request')
 
             if last_request.method != method:
-                raise ValueError(f'can not use endpoint from previous request, it has different method')
+                raise ValueError('can not use endpoint from previous request, it has different method')
 
             endpoint = last_request.endpoint
             content_type = last_request.response.content_type
@@ -199,7 +199,7 @@ def handler_logic(
     input_context: Tuple[TransformerContentType, Any],
     expression: str,
     match_with: str,
-    user: ContextVariables,
+    user: GrizzlyUser,
     callback: Callable[[str, Optional[Any]], None],
     condition: bool,
 ) -> None:
@@ -264,7 +264,7 @@ def generate_validation_handler(expression: str, match_with: str, condition: boo
     '''
     def validate(
         input_context: Tuple[TransformerContentType, Any],
-        user: ContextVariables,
+        user: GrizzlyUser,
         response: Optional[ResponseContextManager] = None,
     ) -> None:
         '''Actual handler that will run after a response has been received by an task.
@@ -284,7 +284,7 @@ def generate_validation_handler(expression: str, match_with: str, condition: boo
                 interpolated_expression (str): `expression` with templating variables resolved
                 match (Optional[Any]): value based on `expression` that matches `match_with`
             '''
-            result = match is not None if condition == True else match is None
+            result = match is not None if condition is True else match is None
 
             if result:
                 message = f'"{interpolated_expression}": "{match_with} was {match}"'
@@ -311,7 +311,7 @@ def generate_save_handler(expression: str, match_with: str, variable: str) -> Ha
     '''
     def save(
         input_context: Tuple[TransformerContentType, Any],
-        user: ContextVariables,
+        user: GrizzlyUser,
         response: Optional[ResponseContextManager] = None,
     ) -> None:
         '''Actual handler that will run after a response has been received by an task.
@@ -357,7 +357,7 @@ def _add_response_handler(
     scenario_tasks_count = len(context.scenario.tasks)
 
     if variable is not None and variable not in context.state.variables:
-        raise ValueError(f'variable {variable} has not been declared')
+        raise ValueError(f'variable "{variable}" has not been declared')
 
     if not scenario_tasks_count > 0:
         raise ValueError('no request source has been added!')
@@ -371,10 +371,13 @@ def _add_response_handler(
     if not isinstance(request, RequestTask):
         raise ValueError('latest task was not a request')
 
+    if request.response.content_type == TransformerContentType.UNDEFINED:
+        raise ValueError('content type is not set for latest request')
+
     if '{{' in match_with and '}}' in match_with:
         context.scenario.orphan_templates.append(match_with)
 
-    if '{{' in expression and '}}' in match_with:
+    if '{{' in expression and '}}' in expression:
         context.scenario.orphan_templates.append(expression)
 
     if action == ResponseAction.SAVE:
@@ -406,5 +409,3 @@ def add_validation_handler(context: GrizzlyContext, target: ResponseTarget, expr
 
 def normalize_step_name(step_name: str) -> str:
     return re.sub(r'"[^"]*"', '""', step_name)
-
-
