@@ -6,7 +6,7 @@ import jinja2 as j2
 
 from jinja2.nodes import Getattr, Getitem, Name
 
-from ..task import RequestTask
+from ..tasks import RequestTask
 
 
 RequestSourceMapping = Dict[str, Set[Tuple[str, Union[str, RequestTask]]]]
@@ -41,6 +41,7 @@ def get_template_variables(sources: Optional[List[RequestTask]]) -> Dict[str, Se
 
     return _parse_templates(templates)
 
+
 def walk_attr(node: Getattr) -> List[str]:
     def _walk_attr(parent: Getattr) -> List[str]:
         attributes: List[str] = [getattr(parent, 'attr')]
@@ -83,7 +84,7 @@ def _parse_templates(requests: RequestSourceMapping) -> Dict[str, Set[str]]:
                     template_source = request.source
                 sources += [request.name, request.endpoint]
             else:
-                template_source = cast(j2.BaseLoader, j2env.loader).get_source(j2env, request)[0]
+                template_source = j2env.loader.get_source(j2env, request)[0]
 
             if template_source is not None:
                 sources.append(template_source)
