@@ -21,6 +21,7 @@ content type, which needs to be specified as an argument (e.g. XPATH expressions
 * `repeat` _bool_ (optional) - if `True`, values read for the queue will be saved in a list and re-used if there are no new messages available
 * `url` _str_ - see format of url below.
 * `wait` _int_ - number of seconds to wait for a message on the queue
+* `heartbeat_interval` _int_ - number of seconds to use for the heartbeat interval (default 300)
 
 ### URL format
 
@@ -65,13 +66,15 @@ When the scenario starts `grizzly` will wait up to 120 seconds until `AtomicMess
 
 If there are no messages within 120 seconds, and it is the first iteration of the scenario, it will fail. If there has been at least one message on the queue since
 the scenario started, it will use the oldest of those values, and then add it back in the end of the list again.
-'''
+'''  # noqa: E501
 import logging
 
 from typing import Dict, Any, Type, Optional, List, cast
 from urllib.parse import urlparse, parse_qs, unquote
 
-import zmq
+from zmq.error import Again as ZMQAgain, ZMQError
+from zmq.sugar.constants import NOBLOCK as ZMQ_NOBLOCK, REQ as ZMQ_REQ
+import zmq.green as zmq
 
 from gevent import sleep as gsleep
 from grizzly_extras.async_message import AsyncMessageContext, AsyncMessageRequest, AsyncMessageResponse
@@ -105,7 +108,7 @@ def atomicmessagequeue__base_type__(value: str) -> str:
         raise ValueError(f'AtomicMessageQueue: {str(e)}') from e
 
     if 'queue' not in endpoint:
-        raise ValueError(f'AtomicMessageQueue: queue name must be prefixed with queue:')
+        raise ValueError('AtomicMessageQueue: queue name must be prefixed with queue:')
 
     for argument in ['url']:
         if argument not in arguments:
@@ -116,13 +119,14 @@ def atomicmessagequeue__base_type__(value: str) -> str:
             raise ValueError(f'AtomicMessageQueue: argument {argument_name} is not allowed')
         else:
             AtomicMessageQueue.arguments[argument_name](argument_value)
-            if argument_name == 'wait':
+            if argument_name in ['wait', 'heartbeat_interval']:
                 int(argument_value)
 
     # validate url
     AtomicMessageQueue.create_context({
         'url': arguments['url'],
         'wait': arguments.get('wait', None),
+        'heartbeat_interval': arguments.get('heartbeat_interval', None),
     })
 
     return f'{queue} | {queue_arguments}'
@@ -142,7 +146,13 @@ class AtomicMessageQueue(AtomicVariable[str]):
     _zmq_url = 'tcp://127.0.0.1:5554'
     _zmq_context: zmq.Context
 
-    arguments: Dict[str, Any] = {'content_type': TransformerContentType.from_string, 'repeat': bool_typed, 'url': str, 'wait': int}
+    arguments: Dict[str, Any] = {
+        'content_type': TransformerContentType.from_string,
+        'repeat': bool_typed,
+        'url': str,
+        'wait': int,
+        'heartbeat_interval': int,
+    }
 
     def __init__(self, variable: str, value: str):
         if pymqi.__name__ == 'grizzly_extras.dummy_pymqi':
@@ -154,7 +164,7 @@ class AtomicMessageQueue(AtomicVariable[str]):
 
         safe_value = self.__class__.__base_type__(value)
 
-        settings = {'repeat': False, 'wait': None, 'url': None, 'worker': None, 'context': None}
+        settings = {'repeat': False, 'wait': None, 'heartbeat_interval': None, 'url': None, 'worker': None, 'context': None}
 
         queue_name, queue_arguments = split_value(safe_value)
 
@@ -266,12 +276,16 @@ class AtomicMessageQueue(AtomicVariable[str]):
             'cert_label': cert_label,
             'ssl_cipher': ssl_cipher,
             'message_wait': settings.get('wait', None),
+            'heartbeat_interval': settings.get('heartbeat_interval', None),
         }
 
     def create_client(self, variable: str, settings: Dict[str, Any]) -> zmq.Socket:
         self._settings[variable].update({'context': self.create_context(settings)})
 
-        zmq_client = cast(zmq.Socket, self._zmq_context.socket(zmq.REQ))
+        zmq_client = cast(
+            zmq.Socket,
+            self._zmq_context.socket(ZMQ_REQ),
+        )
         zmq_client.connect(self._zmq_url)
 
         return zmq_client
@@ -327,9 +341,9 @@ class AtomicMessageQueue(AtomicVariable[str]):
 
                 while True:
                     try:
-                        response = self._endpoint_clients[variable].recv_json(flags=zmq.NOBLOCK)
+                        response = self._endpoint_clients[variable].recv_json(flags=ZMQ_NOBLOCK)
                         break
-                    except zmq.Again:
+                    except ZMQAgain:
                         gsleep(0.1)
 
                 if response is None:
@@ -352,16 +366,15 @@ class AtomicMessageQueue(AtomicVariable[str]):
             if 'content_type' in self._settings[variable]:
                 request['context']['content_type'] = self._settings[variable]['content_type'].name.lower()
 
-
             self._endpoint_clients[variable].send_json(request)
 
             response = None
 
             while True:
                 try:
-                    response = cast(AsyncMessageResponse, self._endpoint_clients[variable].recv_json(flags=zmq.NOBLOCK))
+                    response = cast(AsyncMessageResponse, self._endpoint_clients[variable].recv_json(flags=ZMQ_NOBLOCK))
                     break
-                except zmq.Again:
+                except ZMQAgain:
                     gsleep(0.1)
 
             if response is None:
@@ -397,7 +410,7 @@ class AtomicMessageQueue(AtomicVariable[str]):
                 del self._endpoint_messages[variable]
                 try:
                     self._endpoint_clients[variable].disconnect(self._zmq_url)
-                except zmq.ZMQError:
+                except ZMQError:
                     pass
                 del self._endpoint_clients[variable]
             except KeyError:
