@@ -45,6 +45,9 @@ Then put request "test/queue-message.j2.json" with name "queue-message" to endpo
 Default behavior is to fail directly if there is no message on the queue. If the request should wait until a message is available,
 set the time it should wait with `message.wait` (seconds) context variable.
 
+To keep the connection alive during longer waiting periods, a heartbeat interval can be configured using the
+`connection.heartbeat_interval` (seconds) context variable (default 300).
+
 ```gherkin
 Given a user of type "MessageQueue" load testing "mq://mq.example.com/?QueueManager=QM01&Channel=SRVCONN01"
 And set context variable "message.wait" to "5"
@@ -100,19 +103,20 @@ from urllib.parse import urlparse, parse_qs, unquote
 from contextlib import contextmanager
 from time import perf_counter as time
 
-import zmq
+from zmq.sugar.constants import NOBLOCK as ZMQ_NOBLOCK, REQ as ZMQ_REQ
+from zmq.error import Again as ZMQAgain
+import zmq.green as zmq
 
-from gevent import sleep as gsleep
 from locust.exception import StopUser
-from grizzly.types import RequestDirection
+from locust.env import Environment
+from gevent import sleep as gsleep
 from grizzly_extras.async_message import AsyncMessageContext, AsyncMessageRequest, AsyncMessageResponse, AsyncMessageError
 from grizzly_extras.arguments import get_unsupported_arguments, parse_arguments
-from grizzly_extras.transformer import TransformerContentType
 
 from ..types import GrizzlyResponse, RequestDirection
-from ..task import RequestTask
+from ..tasks import RequestTask
 from ..utils import merge_dicts
-from .meta import ContextVariables, ResponseHandler, RequestLogger
+from .base import GrizzlyUser, ResponseHandler, RequestLogger
 from . import logger
 
 
@@ -124,7 +128,8 @@ try:
 except:
     from grizzly_extras import dummy_pymqi as pymqi
 
-class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
+
+class MessageQueueUser(ResponseHandler, RequestLogger, GrizzlyUser):
     _context: Dict[str, Any] = {
         'auth': {
             'username': None,
@@ -146,14 +151,14 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
     zmq_client: zmq.Socket
     zmq_url = 'tcp://127.0.0.1:5554'
 
-    def __init__(self, *args: Tuple[Any, ...], **kwargs: Dict[str, Any]) -> None:
+    def __init__(self, environment: Environment, *args: Tuple[Any, ...], **kwargs: Dict[str, Any]) -> None:
         if pymqi.__name__ == 'grizzly_extras.dummy_pymqi':
             raise NotImplementedError('MessageQueueUser could not import pymqi, have you installed IBM MQ dependencies?')
 
-        super().__init__(*args, **kwargs)
+        super().__init__(environment, *args, **kwargs)
 
         # Get configuration values from host string
-        parsed = urlparse(self.host)
+        parsed = urlparse(self.host or '')
 
         if parsed.scheme != 'mq':
             raise ValueError(f'"{parsed.scheme}" is not a supported scheme for {self.__class__.__name__}')
@@ -170,7 +175,7 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
         port = parsed.port or 1414
 
         self.am_context = {
-            'url': self.host,
+            'url': self.host or '',
             'connection': f'{parsed.hostname}({port})',
         }
 
@@ -199,6 +204,7 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
             'cert_label': auth_context.get('cert_label', None) or username,
             'ssl_cipher': auth_context.get('ssl_cipher', None) or 'ECDHE_RSA_AES_256_GCM_SHA384',
             'message_wait': self._context.get('message', {}).get('wait', None),
+            'heartbeat_interval': self._context.get('connection', {}).get('heartbeat_interval', None),
         })
 
         self.worker_id = None
@@ -207,7 +213,6 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
         for uamqp_logger_name in ['uamqp', 'uamqp.c_uamqp']:
             logging.getLogger(uamqp_logger_name).setLevel(logging.ERROR)
 
-
     def request(self, request: RequestTask) -> GrizzlyResponse:
         request_name, endpoint, payload = self.render(request)
 
@@ -233,9 +238,9 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
                 # do not block all other "threads", just it self
                 while True:
                     try:
-                        response = cast(AsyncMessageResponse, self.zmq_client.recv_json(flags=zmq.NOBLOCK))
+                        response = cast(AsyncMessageResponse, self.zmq_client.recv_json(flags=ZMQ_NOBLOCK))
                         break
-                    except zmq.Again:
+                    except ZMQAgain:
                         gsleep(0.1)
 
             except Exception as e:
@@ -260,7 +265,6 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
                 else:
                     response = {}
 
-
                 action['metadata'] = response.get('metadata', None)
                 action['payload'] = response.get('payload', None)
 
@@ -316,7 +320,7 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
                     'meta': True,
                     'failure_exception': request.scenario.failure_exception,
                 })
-                self.zmq_client = self.zmq_context.socket(zmq.REQ)
+                self.zmq_client = self.zmq_context.socket(ZMQ_REQ)
                 self.zmq_client.connect(self.zmq_url)
 
         am_request: AsyncMessageRequest = {
@@ -328,8 +332,7 @@ class MessageQueueUser(ResponseHandler, RequestLogger, ContextVariables):
             'payload': payload,
         }
 
-        if request.response.content_type != TransformerContentType.GUESS:
-            am_request['context']['content_type'] = request.response.content_type.name.lower()
+        am_request['context']['content_type'] = request.response.content_type.name.lower()
 
         with wrap_action(am_request, name) as action:
             action['failure_exception'] = StopUser
