@@ -72,22 +72,24 @@ from urllib.parse import urlparse, parse_qs
 from time import perf_counter as time
 from contextlib import contextmanager
 
-import zmq
+from zmq.error import Again as ZMQAgain
+from zmq.sugar.constants import NOBLOCK as ZMQ_NOBLOCK, REQ as ZMQ_REQ
+import zmq.green as zmq
 
 from locust.exception import StopUser
+from locust.env import Environment
 from gevent import sleep as gsleep
 from grizzly_extras.async_message import AsyncMessageContext, AsyncMessageResponse, AsyncMessageRequest, AsyncMessageError
 from grizzly_extras.arguments import parse_arguments, get_unsupported_arguments
-from grizzly_extras.transformer import TransformerContentType
 
 from ..types import RequestMethod, RequestDirection, GrizzlyResponse
-from ..task import RequestTask
+from ..tasks import RequestTask
 from ..utils import merge_dicts
-from .meta import ContextVariables, ResponseHandler, RequestLogger
+from .base import GrizzlyUser, ResponseHandler, RequestLogger
 from . import logger
 
 
-class ServiceBusUser(ResponseHandler, RequestLogger, ContextVariables):
+class ServiceBusUser(ResponseHandler, RequestLogger, GrizzlyUser):
     _context: Dict[str, Any] = {
         'message': {
             'wait': None,
@@ -105,14 +107,8 @@ class ServiceBusUser(ResponseHandler, RequestLogger, ContextVariables):
 
     host: str
 
-    request_name_map: Dict[str, str] = {
-        'RECEIVE': 'RECV',
-        'HELLO': 'HELO',
-    }
-
-
-    def __init__(self, *args: Tuple[Any], **kwargs: Dict[str, Any]) -> None:
-        super().__init__(*args, **kwargs)
+    def __init__(self, environment: Environment, *args: Tuple[Any], **kwargs: Dict[str, Any]) -> None:
+        super().__init__(environment, *args, **kwargs)
 
         if not self.host.startswith('Endpoint='):
             conn_str = self.host
@@ -153,10 +149,10 @@ class ServiceBusUser(ResponseHandler, RequestLogger, ContextVariables):
 
         self.hellos = set()
         self.worker_id = None
-        self.zmq_client = self.zmq_context.socket(zmq.REQ)
+        self.zmq_client = self.zmq_context.socket(ZMQ_REQ)
         self.zmq_client.connect(self.zmq_url)
 
-        if self._scenario is not None:
+        if getattr(self, '_scenario', None) is not None:
             for task in self._scenario.tasks:
                 if not isinstance(task, RequestTask):
                     continue
@@ -247,8 +243,7 @@ class ServiceBusUser(ResponseHandler, RequestLogger, ContextVariables):
             'payload': None,
         }
 
-        if task.response.content_type != TransformerContentType.GUESS:
-            request['context']['content_type'] = task.response.content_type.name.lower()
+        request['context']['content_type'] = task.response.content_type.name.lower()
 
         response: Optional[AsyncMessageResponse] = None
         exception: Optional[Exception] = None
@@ -262,9 +257,9 @@ class ServiceBusUser(ResponseHandler, RequestLogger, ContextVariables):
 
             while True:
                 try:
-                    response = cast(AsyncMessageResponse, self.zmq_client.recv_json(flags=zmq.NOBLOCK))
+                    response = cast(AsyncMessageResponse, self.zmq_client.recv_json(flags=ZMQ_NOBLOCK))
                     break
-                except zmq.Again:
+                except ZMQAgain:
                     gsleep(0.1)
         except Exception as e:
             exception = e
@@ -302,7 +297,7 @@ class ServiceBusUser(ResponseHandler, RequestLogger, ContextVariables):
                 if exception is None:
                     exception = e
             finally:
-                action_name = self.request_name_map.get(request['action'], request['action'][:4])
+                action_name = self.get_request_method(task)
                 self.environment.events.request.fire(
                     request_type=f'sb:{action_name}',
                     name=name,
@@ -356,4 +351,3 @@ class ServiceBusUser(ResponseHandler, RequestLogger, ContextVariables):
             action['failure_exception'] = request.scenario.failure_exception
 
         return action['metadata'], action['payload']
-
