@@ -1,7 +1,7 @@
 import logging
 import re
 
-from typing import Generic, Type, List, Any, Dict, Tuple, Optional, cast, Generator
+from typing import TYPE_CHECKING, Generic, Type, List, Any, Dict, Tuple, Optional, cast, Generator
 from types import FunctionType
 from importlib import import_module
 from functools import wraps
@@ -12,12 +12,15 @@ from copy import deepcopy
 from behave.runner import Context
 from behave.model import Scenario
 from behave.model_core import Status
-from locust.user.users import User
-from locust import TaskSet, between
+from locust import between
 
 from .context import GrizzlyContextScenario
 from .types import WrappedFunc, T
 
+if TYPE_CHECKING:  # pragma: no cover
+    from .scenarios import GrizzlyScenario
+    from .users.base import GrizzlyUser
+
 
 logger = logging.getLogger(__name__)
 
@@ -87,7 +90,7 @@ def fail_direct(context: Context) -> Generator[None, None, None]:
     context.config.verbose = orig_verbose_value
 
 
-def create_user_class_type(scenario: GrizzlyContextScenario, global_context: Optional[Dict[str, Any]] = None) -> Type[User]:
+def create_user_class_type(scenario: GrizzlyContextScenario, global_context: Optional[Dict[str, Any]] = None) -> Type['GrizzlyUser']:
     if global_context is None:
         global_context = {}
 
@@ -103,23 +106,21 @@ def create_user_class_type(scenario: GrizzlyContextScenario, global_context: Opt
         module = 'grizzly.users'
         user_class_name = scenario.user.class_name
 
-    base_user_class_type = cast(Type[User], ModuleLoader[User].load(module, user_class_name))
+    base_user_class_type = cast(Type['GrizzlyUser'], ModuleLoader['GrizzlyUser'].load(module, user_class_name))
     user_class_name = f'{scenario.user.class_name}_{scenario.identifier}'
 
     context: Dict[str, Any] = {}
-    contexts: List[Dict[str, Any]] = []
+    contexts: List[Dict[str, Any]] = [
+        base_user_class_type._context,
+        global_context,
+        scenario.context,
+    ]
 
-    from .users.meta import ContextVariables
-
-    if issubclass(base_user_class_type, ContextVariables):
-        contexts.append(base_user_class_type._context)
-
-    contexts += [global_context, scenario.context]
-
-    for merge_context in [base_user_class_type._context, global_context, scenario.context]:
+    for merge_context in contexts:
         context = merge_dicts(context, merge_context)
 
     return type(user_class_name, (base_user_class_type, ), {
+        '__module__': base_user_class_type.__module__,
         '__dependencies__': base_user_class_type.__dependencies__,
         '_context': context,
         '_scenario': scenario,
@@ -127,16 +128,17 @@ def create_user_class_type(scenario: GrizzlyContextScenario, global_context: Opt
     })
 
 
-def create_scenario_class_type(base_type: str, scenario: GrizzlyContextScenario) -> Type[TaskSet]:
+def create_scenario_class_type(base_type: str, scenario: GrizzlyContextScenario) -> Type['GrizzlyScenario']:
     if base_type.count('.') > 0:
         module, base_type = base_type.rsplit('.', 1)
     else:
         module = 'grizzly.scenarios'
 
-    base_task_class_type = cast(Type[TaskSet], ModuleLoader[TaskSet].load(module, base_type))
+    base_task_class_type = ModuleLoader['GrizzlyScenario'].load(module, base_type)
     task_class_name = f'{base_type}_{scenario.identifier}'
 
     return type(task_class_name, (base_task_class_type, ), {
+        '__module__': base_task_class_type.__module__,
         'tasks': [],
         'wait_time': between(scenario.wait.minimum, scenario.wait.maximum)
     })
@@ -175,10 +177,10 @@ def parse_timespan(timespan: str) -> Dict[str, int]:
     pattern = re.compile(r'((?P<years>-?\d+?)Y)?((?P<months>-?\d+?)M)?((?P<days>-?\d+?)D)?((?P<hours>-?\d+?)h)?((?P<minutes>-?\d+?)m)?((?P<seconds>-?\d+?)s)?')
     parts = pattern.match(timespan)
     if not parts:
-        raise ValueError('invalid time span format')
+        raise ValueError(f'invalid time span format: {timespan}')
     group = parts.groupdict()
     parameters = {name: int(value) for name, value in group.items() if value}
     if not parameters:
-        raise ValueError('invalid time span format')
+        raise ValueError(f'invalid time span format: {timespan}')
 
     return parameters
